package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.text.Convert;
import com.ruoyi.system.domain.ApplyChild;
import com.ruoyi.system.mapper.ApplyChildMapper;
import com.ruoyi.system.service.IApplyChildService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 开通申请子系统Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-10-27
 */
@Service
public class ApplyChildServiceImpl implements IApplyChildService
{
    @Autowired
    private ApplyChildMapper applyChildMapper;

    /**
     * 查询开通申请子系统
     * 
     * @param childId 开通申请子系统ID
     * @return 开通申请子系统
     */
    @Override
    public ApplyChild selectApplyChildById(Long childId)
    {
        return applyChildMapper.selectApplyChildById(childId);
    }

    /**
     * 查询开通申请子系统列表
     * 
     * @param applyChild 开通申请子系统
     * @return 开通申请子系统
     */
    @Override
    public List<ApplyChild> selectApplyChildList(ApplyChild applyChild)
    {
        return applyChildMapper.selectApplyChildList(applyChild);
    }

    /**
     * 新增开通申请子系统
     * 
     * @param applyChild 开通申请子系统
     * @return 结果
     */
    @Override
    public int insertApplyChild(ApplyChild applyChild)
    {
        return applyChildMapper.insertApplyChild(applyChild);
    }

    /**
     * 修改开通申请子系统
     * 
     * @param applyChild 开通申请子系统
     * @return 结果
     */
    @Override
    public int updateApplyChild(ApplyChild applyChild)
    {
        return applyChildMapper.updateApplyChild(applyChild);
    }

    /**
     * 删除开通申请子系统对象
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    @Override
    public int deleteApplyChildByIds(String ids)
    {
        return applyChildMapper.deleteApplyChildByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除开通申请子系统信息
     * 
     * @param childId 开通申请子系统ID
     * @return 结果
     */
    @Override
    public int deleteApplyChildById(Long childId)
    {
        return applyChildMapper.deleteApplyChildById(childId);
    }
}
